<?php
/**
 * Adjust the Charge functionality for Pro.
 *
 * @since 3.5.0
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Save the "Shipping Address" fields to the charge.
 *
 * If "Same billing & shipping info" is checked, use the billing address data.
 *
 * @since 3.5.0
 *
 * @param array $args Charge arguments.
 * @return array
 */
function simpay_pro_stripe_charge_args_shipping( $args ) {
	$type    = isset( $_POST['simpay_same_billing_shipping'] ) ? 'billing' : 'shipping';
	$address = simpay_get_form_address_data( $type, $_POST );

	if ( $address && ! empty( $address ) ) {
		$args['shipping']['address'] = $address;

		// A name is required if `shipping` is set.
		// Check if any existing data exists, and use that if there is.
		$name = isset( $args['shipping']['name'] ) ? $args['shipping']['name'] : '';

		// Check for shipping name from Stripe Checkout.
		if ( isset( $_POST['simpay_customer_name'] ) ) {
			$name = sanitize_text_field( $_POST['simpay_customer_name'] );
		}

		$args['shipping']['name'] = $name;

		// Add a phone number if it exists.
		if ( isset( $_POST['simpay_telephone'] ) ) {
			$args['shipping']['phone'] = sanitize_text_field( $_POST['simpay_telephone'] );
		}
	}

	return $args;
}
add_filter( 'simpay_stripe_charge_args', 'simpay_pro_stripe_charge_args_shipping', 20 );
