<?php
/**
 * Adjust the Customer functionality for Pro.
 *
 * @since 3.5.0
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Save the "Shipping Address" fields to the customer.
 *
 * @since 3.5.0
 *
 * @param array $args Customer arguments.
 * @return array
 */
function simpay_pro_stripe_customer_args_shipping( $args ) {
	$address = simpay_get_form_address_data( 'shipping', $_POST );

	if ( $address && ! empty( $address ) ) {
		$args['shipping']['address'] = $address;

		// A name is required if `shipping` is set.
		$name = '';

		// Check for shipping name from Stripe Checkout.
		if ( isset( $_POST['simpay_customer_name'] ) ) {
			$name = sanitize_text_field( $_POST['simpay_customer_name'] );
		}

		$args['shipping']['name'] = $name;
	}

	// Add a phone number if it exists.
	if ( isset( $_POST['simpay_telephone'] ) ) {
		$phone = sanitize_text_field( $_POST['simpay_telephone'] );

		$args['phone'] = $phone;
	}

	return $args;
}
add_filter( 'simpay_stripe_customer_args', 'simpay_pro_stripe_customer_args_shipping' );

/**
 * Add a coupon to a customer if one exists.
 *
 * @since 3.5.0
 *
 * @param array $args Arguments passed to customer creation in Stripe.
 * @return array $args
 */
function simpay_pro_stripe_customer_args_coupon( $args ) {
	if ( isset( $_POST['simpay_coupon'] ) && ! empty( $_POST['simpay_coupon'] ) ) {
		$args['coupon'] = sanitize_text_field( $_POST['simpay_coupon'] );
	}

	return $args;
}
add_filter( 'simpay_stripe_customer_args', 'simpay_pro_stripe_customer_args_coupon' );
